@@ -1,5 +1,5 @@
 from office365.entity import Entity
-from office365.runtime.types.string_collection import StringCollection
+from office365.runtime.types.collections import StringCollection
 
 
 class ApplicationTemplate(Entity):
