@@ -4,6 +4,7 @@ from office365.directory.applications.app_role_assignment import AppRoleAssignme
 from office365.directory.licenses.assigned_license import AssignedLicense
 from office365.directory.directory_object import DirectoryObject
 from office365.directory.directory_object_collection import DirectoryObjectCollection
+from office365.directory.resource_specific_permission_grant import ResourceSpecificPermissionGrant
 from office365.entity_collection import EntityCollection, DeltaCollection
 from office365.onedrive.drives.drive import Drive
 from office365.onenote.onenote import Onenote
@@ -12,7 +13,7 @@ from office365.planner.planner_group import PlannerGroup
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.teams.internal.paths.team import TeamPath
 from office365.teams.team import Team
@@ -36,6 +37,12 @@ class Group(DirectoryObject):
         self.context.add_query(qry)
         return self
 
+    def check_granted_permissions_for_app(self):
+        return_type = EntityCollection(self.context, ResourceSpecificPermissionGrant)
+        qry = ServiceOperationQuery(self, "checkGrantedPermissionsForApp", None, None, None, return_type)
+        self.context.add_query(qry)
+        return return_type
+
     def remove_favorite(self):
         """
         Remove the group from the list of the current user's favorite groups. Supported for Microsoft 365 groups only.
@@ -75,7 +82,8 @@ class Group(DirectoryObject):
         of groups provisioned in Azure AD. Note that Microsoft 365 groups cannot contain groups.
         So membership in a Microsoft 365 group is always direct.
 
-        :type group_ids: list[str]
+        :param list[str] group_ids: A collection that contains the object IDs of the groups in which to
+            check membership. Up to 20 groups may be specified.
         """
         result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "checkMemberGroups", None, group_ids, None, result)
@@ -117,20 +125,18 @@ class Group(DirectoryObject):
 
         :rtype: DirectoryObjectCollection
         """
-        return self.get_property('members',
-                                 DirectoryObjectCollection(self.context, ResourcePath("members", self.resource_path)))
+        return self.properties.get('members',
+                                   DirectoryObjectCollection(self.context, ResourcePath("members", self.resource_path)))
 
     @property
     def transitive_members(self):
         """
         Get a list of the group's members. A group can have users, devices, organizational contacts,
         and other groups as members. This operation is transitive and returns a flat list of all nested members.
-
-        :rtype: DirectoryObjectCollection
         """
-        return self.get_property('transitiveMembers',
-                                 DirectoryObjectCollection(self.context,
-                                                           ResourcePath("transitiveMembers", self.resource_path)))
+        return self.properties.get('transitiveMembers',
+                                   DirectoryObjectCollection(self.context,
+                                                             ResourcePath("transitiveMembers", self.resource_path)))
 
     @property
     def transitive_member_of(self):
@@ -138,30 +144,24 @@ class Group(DirectoryObject):
         Get groups that the group is a member of. This operation is transitive and will also include all groups that
         this groups is a nested member of. Unlike getting a user's Microsoft 365 groups, this returns all
         types of groups, not just Microsoft 365 groups.
-
-        :rtype: DirectoryObjectCollection
         """
-        return self.get_property('transitiveMemberOf',
-                                 DirectoryObjectCollection(self.context,
-                                                           ResourcePath("transitiveMemberOf", self.resource_path)))
+        return self.properties.get('transitiveMemberOf',
+                                   DirectoryObjectCollection(self.context,
+                                                             ResourcePath("transitiveMemberOf", self.resource_path)))
 
     @property
     def owners(self):
         """The owners of the group.
-
-        :rtype: DirectoryObjectCollection
         """
-        return self.get_property('owners',
-                                 DirectoryObjectCollection(self.context, ResourcePath("owners", self.resource_path)))
+        return self.properties.get('owners',
+                                   DirectoryObjectCollection(self.context, ResourcePath("owners", self.resource_path)))
 
     @property
     def drives(self):
         """The group's drives. Read-only.
-
-        :rtype: EntityCollection
         """
-        return self.get_property('drives',
-                                 EntityCollection(self.context, Drive, ResourcePath("drives", self.resource_path)))
+        return self.properties.get('drives',
+                                   EntityCollection(self.context, Drive, ResourcePath("drives", self.resource_path)))
 
     @property
     def sites(self):
@@ -170,8 +170,8 @@ class Group(DirectoryObject):
         :rtype: SiteCollection
         """
         from office365.onedrive.sites.sites_with_root import SitesWithRoot
-        return self.get_property('sites',
-                                 SitesWithRoot(self.context, ResourcePath("sites", self.resource_path)))
+        return self.properties.get('sites',
+                                   SitesWithRoot(self.context, ResourcePath("sites", self.resource_path)))
 
     @property
     def events(self):
@@ -205,9 +205,9 @@ class Group(DirectoryObject):
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
+                "appRoleAssignments": self.app_role_assignments,
                 "transitiveMembers": self.transitive_members,
                 "transitiveMemberOf": self.transitive_member_of,
-                "appRoleAssignments": self.app_role_assignments
             }
             default_value = property_mapping.get(name, None)
         return super(Group, self).get_property(name, default_value)
