@@ -1,5 +1,5 @@
 from office365.runtime.client_object_collection import ClientObjectCollection
-from office365.runtime.queries.create_entity_query import CreateEntityQuery
+from office365.runtime.queries.create_entity import CreateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
 
 
