@@ -26,14 +26,13 @@ from office365.reports.report_root import ReportRoot
 from office365.runtime.auth.token_response import TokenResponse
 from office365.runtime.client_runtime_context import ClientRuntimeContext
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.odata_request import ODataRequest
 from office365.runtime.odata.v4.batch_request import ODataV4BatchRequest
 from office365.runtime.odata.v4.json_format import V4JsonFormat
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.queries.batch_query import BatchQuery
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
-from office365.runtime.queries.update_entity_query import UpdateEntityQuery
+from office365.runtime.queries.batch import BatchQuery
+from office365.runtime.queries.delete_entity import DeleteEntityQuery
+from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.search.search_entity import SearchEntity
 from office365.teams.chats.chat import Chat
 from office365.teams.team_collection import TeamCollection
@@ -64,7 +63,7 @@ class GraphClient(ClientRuntimeContext):
         return request
 
     def execute_batch(self):
-        """Construct and submit a batch request"""
+        """Constructs and submit a batch request"""
         batch_request = ODataV4BatchRequest(self)
         queries = [qry for qry in self.pending_request()]
         batch_request.add_query(BatchQuery(self, queries))  # Aggregate requests into batch request
