@@ -3,10 +3,10 @@ from office365.directory.identities.identity_set import IdentitySet
 from office365.entity_collection import EntityCollection
 from office365.onedrive.driveitems.driveItem import DriveItem
 from office365.onedrive.lists.list import List
-from office365.onedrive.internal.paths.root_path import RootPath
+from office365.onedrive.internal.paths.root import RootPath
 from office365.onedrive.driveitems.system_facet import SystemFacet
 from office365.runtime.http.http_method import HttpMethod
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 
 
