@@ -6,33 +6,22 @@ from office365.runtime.types.event_handler import EventHandler
 
 class ClientObjectCollection(ClientObject):
 
-    def __init__(self, context, child_item_type, resource_path=None):
+    def __init__(self, context, item_type, resource_path=None):
         """Client object collection
 
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
-        :type child_item_type: type[ClientObject]
+        :type item_type: type[ClientObject]
         :type resource_path: office365.runtime.paths.resource_path.ResourcePath
         """
         super(ClientObjectCollection, self).__init__(context, resource_path)
         self._data = []
-        self._item_type = child_item_type
+        self._item_type = item_type
         self.page_loaded = EventHandler(False)
         self._page_size = 100
         self._paged_mode = True
         self._page_index = 0
         self.next_request_url = None
 
-    @property
-    def entity_type_name(self):
-        name = super(ClientObjectCollection, self).entity_type_name
-        return "Collection({0})".format(name)
-
-    def get(self):
-        """
-        :rtype: ClientObjectCollection
-        """
-        return super(ClientObjectCollection, self).get()
-
     def clear(self):
         self._data = []
 
@@ -59,8 +48,8 @@ class ClientObjectCollection(ClientObject):
         :type value: any
         :type persist_changes: bool
         """
-        child_client_object = self.create_typed_object(value)
-        self.add_child(child_client_object)
+        client_object = self.create_typed_object(value)
+        self.add_child(client_object)
         return self
 
     def add_child(self, client_object):
@@ -96,9 +85,11 @@ class ClientObjectCollection(ClientObject):
     def __len__(self):
         return len(self._data)
 
+    def __repr__(self):
+        return repr(self._data)
+
     def __getitem__(self, index):
         """
-
         :type index: int
         :rtype: ClientObject
         """
@@ -111,17 +102,19 @@ class ClientObjectCollection(ClientObject):
 
     def filter(self, expression):
         """
-        Sets OData $filter query option
+        Allows clients to filter a collection of resources that are addressed by a request URL
 
-        :type expression: str
+        :type self: T
+        :param str expression: Filter expression, for example: Id eq ''
         """
         self.query_options.filter = expression
         return self
 
     def order_by(self, value):
         """
-        Sets OData $orderBy query option
+        Allows clients to request resources in either ascending order using asc or descending order using desc
 
+        :type self: T
         :type value: int
         """
         self.query_options.orderBy = value
@@ -129,8 +122,9 @@ class ClientObjectCollection(ClientObject):
 
     def skip(self, value):
         """
-        Sets $skip system query option
+        Requests the number of items in the queried collection that are to be skipped and not included in the result
 
+        :type self: T
         :type value: int
         """
         self.query_options.skip = value
@@ -138,6 +132,9 @@ class ClientObjectCollection(ClientObject):
 
     def top(self, value):
         """
+        Specifies the number of items in the queried collection to be included in the result
+
+        :type self: T
         :type value: int
         """
         self._page_size = value
@@ -148,6 +145,7 @@ class ClientObjectCollection(ClientObject):
         """
         Enables/disables server-driven paging
 
+        :type self: T
         :param int value: bool: sets flag to enable/disable server-driven paging
         """
         self._paged_mode = value
@@ -174,6 +172,9 @@ class ClientObjectCollection(ClientObject):
         return result
 
     def _load_next_items(self):
+        """
+        Submit a request to retrieve next collection of items
+        """
         request = RequestOptions(self.next_request_url)
         response = self.context.execute_request_direct(request)
         response.raise_for_status()
@@ -182,3 +183,8 @@ class ClientObjectCollection(ClientObject):
         self.page_loaded.notify(len(self._data))
         self._page_index += 1
         return self._data[self._page_size * self._page_index:]
+
+    @property
+    def entity_type_name(self):
+        name = super(ClientObjectCollection, self).entity_type_name
+        return "Collection({0})".format(name)
