@@ -1,9 +1,11 @@
+
+
 class ClientQuery(object):
     """Client query"""
 
     def __init__(self, context, binding_type=None, parameter_type=None, parameter_name=None, return_type=None):
         """
-        Base query
+        Generic query
 
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
         :type binding_type: office365.runtime.client_object.ClientObject or None
@@ -18,16 +20,20 @@ class ClientQuery(object):
         self._parameter_name = parameter_name
         self._return_type = return_type
 
-    def build_url(self):
-        return self.binding_type.resource_url
-
     def build_request(self):
-        return self.context.build_single_request(self)
+        return self.context.build_request(self)
 
     def execute_query(self):
         self.context.execute_query()
         return self.return_type
 
+    @property
+    def url(self):
+        if self.binding_type is not None:
+            return self.binding_type.resource_url
+        else:
+            return self.context.service_root_url()
+
     @property
     def context(self):
         return self._context
