@@ -1,6 +1,6 @@
 from office365.runtime.client_object import ClientObject
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
-from office365.runtime.queries.update_entity_query import UpdateEntityQuery
+from office365.runtime.queries.delete_entity import DeleteEntityQuery
+from office365.runtime.queries.update_entity import UpdateEntityQuery
 
 
 class BaseEntity(ClientObject):
@@ -17,6 +17,7 @@ class BaseEntity(ClientObject):
 
     def with_credentials(self, credentials):
         """
+        :type self: T
         :type credentials:  UserCredential or ClientCredential
         """
         self.context.with_credentials(credentials)
@@ -47,4 +48,3 @@ class BaseEntity(ClientObject):
         if self._entity_type_name is None:
             self._entity_type_name = ".".join([self._namespace, type(self).__name__])
         return self._entity_type_name
-
