@@ -1,7 +1,6 @@
 import copy
 
 from office365.runtime.auth.authentication_context import AuthenticationContext
-from office365.runtime.auth.client_credential import ClientCredential
 from office365.runtime.auth.providers.saml_token_provider import resolve_base_url
 from office365.runtime.auth.user_credential import UserCredential
 from office365.runtime.client_result import ClientResult
@@ -11,10 +10,10 @@ from office365.runtime.http.request_options import RequestOptions
 from office365.runtime.odata.v3.json_light_format import JsonLightFormat
 from office365.runtime.odata.v3.batch_request import ODataBatchRequest
 from office365.runtime.odata.odata_request import ODataRequest
-from office365.runtime.queries.batch_query import BatchQuery
+from office365.runtime.queries.batch import BatchQuery
 from office365.runtime.queries.client_query import ClientQuery
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
-from office365.runtime.queries.update_entity_query import UpdateEntityQuery
+from office365.runtime.queries.delete_entity import DeleteEntityQuery
+from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.sharepoint.publishing.site_page_service import SitePageService
 from office365.sharepoint.request_user_context import RequestUserContext
@@ -22,7 +21,7 @@ from office365.sharepoint.sites.site import Site
 from office365.sharepoint.tenant.administration.hub_site_collection import HubSiteCollection
 from office365.sharepoint.webs.context_web_information import ContextWebInformation
 from office365.sharepoint.webs.web import Web
-from office365.runtime.compat import range_or_xrange
+from office365.runtime.compat import range_or_xrange, urlparse, is_absolute_url
 
 
 class ClientContext(ClientRuntimeContext):
@@ -30,6 +29,8 @@ class ClientContext(ClientRuntimeContext):
 
     def __init__(self, base_url, auth_context=None):
         """
+        Instantiates a SharePoint client context
+
         :param str base_url: Absolute Web or Site Url
         :param AuthenticationContext or None auth_context: Authentication context
         """
@@ -46,6 +47,21 @@ class ClientContext(ClientRuntimeContext):
         self._ctx_web_info = None
         self._pending_request = None
 
+    def create_safe_url(self, orig_url, relative=True):
+        """
+        Creates a safe url
+
+        :type orig_url: str
+        :type relative: bool
+        """
+        if is_absolute_url(orig_url) and not relative:
+            return orig_url
+
+        site_path = urlparse(self.base_url).path
+        root_site_url = self.base_url.replace(site_path, "")
+        url = orig_url if orig_url.startswith(site_path) else "/".join([site_path, orig_url])
+        return url if relative else "".join([root_site_url, url])
+
     @staticmethod
     def from_url(abs_url):
         """
@@ -142,6 +158,8 @@ class ClientContext(ClientRuntimeContext):
 
     def pending_request(self):
         """
+        Provides access to underlying request instance
+
         :return: ODataRequest
         """
         if self._pending_request is None:
@@ -241,7 +259,7 @@ class ClientContext(ClientRuntimeContext):
         if request.method == HttpMethod.Post:
             self.ensure_form_digest(request)
         # set custom SharePoint control headers
-        if isinstance(self.pending_request().json_format, JsonLightFormat):
+        if isinstance(self.pending_request().default_json_format, JsonLightFormat):
             if isinstance(query, DeleteEntityQuery):
                 request.ensure_header("X-HTTP-Method", "DELETE")
                 request.ensure_header("IF-MATCH", '*')
@@ -279,7 +297,7 @@ class ClientContext(ClientRuntimeContext):
     @property
     def micro_service_manager(self):
         """Alias to MicroServiceManager"""
-        from office365.sharepoint.microservice.micro_service_manager import MicroServiceManager
+        from office365.sharepoint.microservice.manager import MicroServiceManager
         return MicroServiceManager(self, ResourcePath("microServiceManager"))
 
     @property
@@ -294,6 +312,18 @@ class ClientContext(ClientRuntimeContext):
         from office365.sharepoint.portal.group_service import GroupService
         return GroupService(self, ResourcePath("GroupService"))
 
+    @property
+    def people_manager(self):
+        """Alias to PeopleManager"""
+        from office365.sharepoint.userprofiles.people_manager import PeopleManager
+        return PeopleManager(self)
+
+    @property
+    def profile_loader(self):
+        """Alias to ProfileLoader"""
+        from office365.sharepoint.userprofiles.profile_loader import ProfileLoader
+        return ProfileLoader.get_profile_loader(self)
+
     @property
     def lists(self):
         """Alias to ListCollection. Gets information about all lists that the current user can access."""
