@@ -1,31 +1,30 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.fields.field_type import FieldType
+from office365.sharepoint.fields.type import FieldType
 
 
 class Field(BaseEntity):
     """A container for metadata within a SharePoint list and associated list items."""
 
     def __init__(self, context, resource_path=None):
-        super().__init__(context, resource_path)
+        super(Field, self).__init__(context, resource_path)
 
     @staticmethod
     def resolve_field_type(type_id_or_name):
-        from office365.sharepoint.fields.field_calculated import FieldCalculated
-        from office365.sharepoint.fields.field_choice import FieldChoice
-        from office365.sharepoint.fields.field_computed import FieldComputed
-        from office365.sharepoint.fields.field_currency import FieldCurrency
-        from office365.sharepoint.fields.field_guid import FieldGuid
-        from office365.sharepoint.fields.field_lookup import FieldLookup
-        from office365.sharepoint.fields.field_multi_choice import FieldMultiChoice
-        from office365.sharepoint.fields.field_multi_line_text import FieldMultiLineText
-        from office365.sharepoint.fields.field_text import FieldText
-        from office365.sharepoint.fields.field_url import FieldUrl
-        from office365.sharepoint.fields.field_user import FieldUser
-        from office365.sharepoint.taxonomy.taxonomy_field import TaxonomyField
-        from office365.sharepoint.fields.field_date_time import FieldDateTime
+        from office365.sharepoint.fields.calculated import FieldCalculated
+        from office365.sharepoint.fields.choice import FieldChoice
+        from office365.sharepoint.fields.computed import FieldComputed
+        from office365.sharepoint.fields.currency import FieldCurrency
+        from office365.sharepoint.fields.guid import FieldGuid
+        from office365.sharepoint.fields.lookup import FieldLookup
+        from office365.sharepoint.fields.multi_choice import FieldMultiChoice
+        from office365.sharepoint.fields.multi_line_text import FieldMultiLineText
+        from office365.sharepoint.fields.text import FieldText
+        from office365.sharepoint.fields.url import FieldUrl
+        from office365.sharepoint.fields.user import FieldUser
+        from office365.sharepoint.taxonomy.field import TaxonomyField
+        from office365.sharepoint.fields.date_time import FieldDateTime
         field_known_types = {
             FieldType.Text: FieldText,
             FieldType.Calculated: FieldCalculated,
@@ -51,9 +50,10 @@ class Field(BaseEntity):
     @staticmethod
     def create_field_from_type(context, field_parameters):
         """
+        Creates a field based on its type
 
-        :type context: ClientContext
-        :type field_parameters: office365.sharepoint.fields.field_creation_information.FieldCreationInformation
+        :type context: office365.sharepoint.client_context.ClientContext
+        :type field_parameters: office365.sharepoint.fields.creation_information.FieldCreationInformation
         :return: Field
         """
         field_type = Field.resolve_field_type(field_parameters.FieldTypeKind)
@@ -85,20 +85,25 @@ class Field(BaseEntity):
 
     def set_show_in_edit_form(self, flag):
         """Sets the value of the ShowInEditForm property for this fields.
-        :type flag: bool
+
+        :param bool flag: A Boolean value that indicates whether this field is shown in the edit form.
         """
         qry = ServiceOperationQuery(self, "setShowInEditForm", [flag])
         self.context.add_query(qry)
 
     def set_show_in_new_form(self, flag):
-        """Sets the value of the ShowInNewForm property for this fields."""
+        """Sets the value of the ShowInNewForm property for this fields.
+
+        :param bool flag: A Boolean value that indicates whether this field is shown in the new form.
+        """
         qry = ServiceOperationQuery(self, "setShowInNewForm", [flag])
         self.context.add_query(qry)
         return self
 
     @property
     def id(self):
-        """Gets a value that specifies the field identifier.
+        """
+        Gets a value that specifies the field identifier.
 
         :rtype: str or None
         """
@@ -260,8 +265,7 @@ class Field(BaseEntity):
         super(Field, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
         if name == "Id" and self._resource_path is None:
-            self._resource_path = ResourcePathServiceOperation(
-                "getById", [value], self._parent_collection.resource_path)
+            self._resource_path = self.parent_collection.get_by_id(value).resource_path
         if name == "FieldTypeKind":
             self.__class__ = self.resolve_field_type(value)
         elif name == "TypeAsString" and self.properties.get('FieldTypeKind', 0) == 0:
