@@ -1,17 +1,18 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
-from office365.sharepoint.files.file_version_event import FileVersionEvent
+from office365.sharepoint.files.version_event import FileVersionEvent
 from office365.sharepoint.internal.queries.download_file import create_download_file_query
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.directory.user import User
-from office365.sharepoint.files.file_version_collection import FileVersionCollection
+from office365.sharepoint.principal.user import User
+from office365.sharepoint.files.version_collection import FileVersionCollection
 from office365.sharepoint.listitems.listitem import ListItem
-from office365.sharepoint.permissions.information_rights_management_settings import InformationRightsManagementSettings
+from office365.sharepoint.permissions.irm import InformationRightsManagementSettings, \
+    EffectiveInformationRightsManagementSettings
 from office365.sharepoint.webparts.limited_webpart_manager import LimitedWebPartManager
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
 
@@ -51,11 +52,42 @@ class File(AbstractFile):
         file = ctx.web.get_file_by_server_relative_url(file_relative_url)
         return file
 
+    def get_sharing_information(self):
+        """Gets the sharing information for a file."""
+        return self.listItemAllFields.get_sharing_information()
+
+    def share_link(self, link_kind, expiration=None):
+        """Creates a tokenized sharing link for a file based on the specified parameters and optionally
+        sends an email to the people that are listed in the specified parameters.
+
+        :param int link_kind: The kind of the tokenized sharing link to be created/updated or retrieved.
+        :param datetime or None expiration: A date/time string for which the format conforms to the ISO 8601:2004(E)
+            complete representation for calendar date and time of day and which represents the time and date of expiry
+            for the tokenized sharing link. Both the minutes and hour value MUST be specified for the difference
+            between the local and UTC time. Midnight is represented as 00:00:00. A null value indicates no expiry.
+            This value is only applicable to tokenized sharing links that are anonymous access links.
+        """
+        return self.listItemAllFields.share_link(link_kind, expiration)
+
+    def unshare_link(self, link_kind, share_id=None):
+        """
+        Removes the specified tokenized sharing link of the file.
+
+        :param int link_kind: This optional value specifies the globally unique identifier (GUID) of the tokenized
+            sharing link that is intended to be removed.
+        :param str or None share_id: The kind of tokenized sharing link that is intended to be removed.
+        """
+        return self.listItemAllFields.unshare_link(link_kind, share_id)
+
     def get_image_preview_uri(self, width, height, client_type=None):
         """
-        :param int width:
-        :param int height:
-        :param str client_type:
+        Returns the uri where the thumbnail with the closest size to the desired can be found.
+        The actual resolution of the thumbnail might not be the same as the desired values.
+
+
+        :param int width: The desired width of the resolution.
+        :param int height: The desired height of the resolution.
+        :param str client_type: The client type. Used for logging.
         """
         result = ClientResult(self.context)
         payload = {
@@ -69,9 +101,12 @@ class File(AbstractFile):
 
     def get_image_preview_url(self, width, height, client_type=None):
         """
-        :param int width:
-        :param int height:
-        :param str client_type:
+        Returns the url where the thumbnail with the closest size to the desired can be found.
+        The actual resolution of the thumbnail might not be the same as the desired values.
+
+        :param int width: The desired width of the resolution.
+        :param int height: The desired height of the resolution.
+        :param str client_type: The client type. Used for logging.
         """
         result = ClientResult(self.context)
         payload = {
@@ -179,14 +214,10 @@ class File(AbstractFile):
 
     def unpublish(self, comment):
         """Removes the file from content approval or unpublish a major version.
+
         :type comment: str
         """
-        qry = ServiceOperationQuery(self,
-                                    "unpublish",
-                                    {
-                                        "comment": comment,
-                                    }
-                                    )
+        qry = ServiceOperationQuery(self, "unpublish", {"comment": comment})
         self.context.add_query(qry)
         return self
 
@@ -220,9 +251,7 @@ class File(AbstractFile):
 
     def undocheckout(self):
         """Reverts an existing checkout for the file."""
-        qry = ServiceOperationQuery(self,
-                                    "undocheckout"
-                                    )
+        qry = ServiceOperationQuery(self, "UndoCheckout")
         self.context.add_query(qry)
         return self
 
@@ -231,7 +260,7 @@ class File(AbstractFile):
         view. """
         return LimitedWebPartManager(self.context,
                                      ServiceOperationPath(
-                                         "getlimitedwebpartmanager",
+                                         "GetLimitedWebPartManager",
                                          [scope],
                                          self.resource_path
                                      ))
@@ -244,22 +273,30 @@ class File(AbstractFile):
         return return_stream
 
     def save_binary_stream(self, stream):
-        """Saves the file."""
+        """Saves the file in binary format.
+
+        :param str or bytes stream: A stream containing the contents of the specified file.
+        """
         qry = ServiceOperationQuery(self, "SaveBinaryStream", None, {"file": stream})
         self.context.add_query(qry)
         return self
 
     def get_upload_status(self, upload_id):
+        """Gets the status of a chunk upload session.
+
+        :param str upload_id:  The upload session ID.
+        """
         payload = {
             "uploadId": upload_id,
         }
-        qry = ServiceOperationQuery(self, "GetUploadStatus", None, payload)
+        return_type = File(self.context)
+        qry = ServiceOperationQuery(self, "GetUploadStatus", None, payload, None, return_type)
         self.context.add_query(qry)
-        return self
+        return return_type
 
     def upload_with_checksum(self, upload_id, checksum, stream):
         """
-        :param str upload_id:
+        :param str upload_id: The upload session ID.
         :param str checksum:
         :param bytes stream:
         """
@@ -274,6 +311,12 @@ class File(AbstractFile):
         return return_type
 
     def cancel_upload(self, upload_id):
+        """
+        Aborts the chunk upload session without saving the uploaded data. If StartUpload (section 3.2.5.64.2.1.22)
+        created the file, the file will be deleted.
+
+        :param str upload_id:  The upload session ID.
+        """
         payload = {
             "uploadId": upload_id,
         }
@@ -344,10 +387,10 @@ class File(AbstractFile):
         return self
 
     @staticmethod
-    def save_binary(ctx, server_relative_url, content):
+    def save_binary(context, server_relative_url, content):
         """Uploads a file
 
-        :type ctx: ClientContext
+        :type context: office365.sharepoint.client_context.ClientContext
         :type server_relative_url: str
         :type content: str
         """
@@ -356,22 +399,22 @@ class File(AbstractFile):
         request.method = HttpMethod.Post
         request.set_header('X-HTTP-Method', 'PUT')
         request.data = content
-        response = ctx.execute_request_direct(request)
+        response = context.execute_request_direct(request)
         return response
 
     @staticmethod
-    def open_binary(ctx, server_relative_url):
+    def open_binary(context, server_relative_url):
         """
         Returns the file object located at the specified server-relative URL.
 
-        :type ctx: ClientContext
+        :type context: office365.sharepoint.client_context.ClientContext
         :type server_relative_url: str
         :return Response
         """
         url = r"web/getFileByServerRelativePath(DecodedUrl='{0}')/\$value".format(server_relative_url)
         request = RequestOptions(url)
         request.method = HttpMethod.Get
-        response = ctx.execute_request_direct(request)
+        response = context.execute_request_direct(request)
         return response
 
     def download(self, file_object):
@@ -388,11 +431,12 @@ class File(AbstractFile):
         self.ensure_property("ServerRelativePath", _download_inner)
         return self
 
-    def download_session(self, file_object, chunk_downloaded=None, chunk_size=1024 * 1024):
+    def download_session(self, file_object, chunk_downloaded=None, chunk_size=1024 * 1024, use_path=True):
         """
         :type file_object: typing.IO
         :type chunk_downloaded: (int)->None or None
         :type chunk_size: int
+        :param bool use_path: Use Path instead of Url for addressing files
         """
 
         def _download_as_stream():
@@ -423,9 +467,18 @@ class File(AbstractFile):
 
             self.context.add_query(qry)
 
-        self.ensure_property("ServerRelativeUrl", _download_as_stream)
+        if use_path:
+            self.ensure_property("ServerRelativePath", _download_as_stream)
+        else:
+            self.ensure_property("ServerRelativeUrl", _download_as_stream)
         return self
 
+    @property
+    def author(self):
+        """Specifies the user who added the file."""
+        return self.properties.get('Author',
+                                   User(self.context, ResourcePath("Author", self.resource_path)))
+
     @property
     def checked_out_by_user(self):
         """Gets an object that represents the user who has checked out the file."""
@@ -434,19 +487,29 @@ class File(AbstractFile):
 
     @property
     def version_events(self):
+        """Gets the history of events on this version object."""
         return self.properties.get("VersionEvents",
                                    BaseEntityCollection(self.context,
                                                         FileVersionEvent,
                                                         ResourcePath("VersionEvents", self.resource_path)))
 
     @property
-    def information_rights_management_settings(self):
+    def effective_information_rights_management_settings(self):
         """
         Returns the effective Information Rights Management (IRM) settings for the file.
 
-        A file can be IRM-protected based on the IRM settings for the file itself, based on the IRM settings
-        for the list which contains the file, or based on a rule.
-        From greatest to least, IRM settings take precedence in the following order: rule, list, then file.
+        A file can be IRM-protected based on the IRM settings for the file itself, based on the IRM settings for the
+        list which contains the file, or based on a rule. From greatest to least, IRM settings take precedence in the
+        following order: rule, list, then file.
+        """
+        path = ResourcePath("EffectiveInformationRightsManagementSettings", self.resource_path)
+        return self.properties.get('EffectiveInformationRightsManagementSettings',
+                                   EffectiveInformationRightsManagementSettings(self.context, path))
+
+    @property
+    def information_rights_management_settings(self):
+        """
+        Returns the Information Rights Management (IRM) settings for the file.
         """
         return self.properties.get('InformationRightsManagementSettings',
                                    InformationRightsManagementSettings(self.context,
@@ -495,6 +558,7 @@ class File(AbstractFile):
     @property
     def server_relative_path(self):
         """Gets the server-relative Path of the list folder.
+
         :rtype: SPResPath or None
         """
         return self.properties.get("ServerRelativePath", SPResPath())
@@ -602,6 +666,7 @@ class File(AbstractFile):
             property_mapping = {
                 "CheckedOutByUser": self.checked_out_by_user,
                 "VersionEvents": self.version_events,
+                "EffectiveInformationRightsManagementSettings": self.effective_information_rights_management_settings,
                 "InformationRightsManagementSettings": self.information_rights_management_settings,
                 "LockedByUser": self.locked_by_user,
                 "ModifiedBy": self.modified_by
@@ -611,14 +676,15 @@ class File(AbstractFile):
 
     def set_property(self, name, value, persist_changes=True):
         super(File, self).set_property(name, value, persist_changes)
+
+        # prioritize using UniqueId
+        if name == "UniqueId":
+            self._resource_path = self.context.web.get_file_by_id(value).resource_path
+
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "ServerRelativeUrl":
-                self._resource_path = ServiceOperationPath("GetFileByServerRelativeUrl", [value],
-                                                           ResourcePath("Web"))
+                self._resource_path = self.context.web.get_file_by_server_relative_url(value).resource_path
             elif name == "ServerRelativePath":
-                self._resource_path = ServiceOperationPath("getFolderByServerRelativePath", [value],
-                                                           ResourcePath("Web"))
-            elif name == "UniqueId":
-                self._resource_path = ServiceOperationPath("GetFileById", [value], ResourcePath("Web"))
+                self._resource_path = self.context.web.get_file_by_server_relative_path(value).resource_path
         return self
