@@ -1,18 +1,16 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.queries.update_entity_query import UpdateEntityQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
+from office365.runtime.queries.update_entity import UpdateEntityQuery
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity import BaseEntity
-from office365.sharepoint.changes.change_collection import ChangeCollection
-from office365.sharepoint.changes.change_query import ChangeQuery
+from office365.sharepoint.changes.collection import ChangeCollection
+from office365.sharepoint.changes.query import ChangeQuery
 from office365.sharepoint.contenttypes.content_type_id import ContentTypeId
 from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.storagemetrics.storage_metrics import StorageMetrics
 from office365.sharepoint.utilities.move_copy_options import MoveCopyOptions
 from office365.sharepoint.utilities.move_copy_util import MoveCopyUtil
 from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
-from office365.runtime.compat import urlparse
 
 
 class Folder(BaseEntity):
@@ -30,6 +28,78 @@ class Folder(BaseEntity):
         relative_url = abs_url.replace(ctx.base_url, "")
         return ctx.web.get_folder_by_server_relative_url(relative_url)
 
+    def get_sharing_information(self):
+        """Gets the sharing information for a folder."""
+        return self.list_item_all_fields.get_sharing_information()
+
+    def move_to(self, new_url):
+        """
+        Moves the folder and its contents to a new folder at the specified URL.
+        This method applies only to the context of a single site.
+
+        An exception is thrown if a folder with the same name as specified in the parameter already exists.
+
+        :param str new_url: A string that specifies the URL for the new folder.
+        """
+        return_type = Folder(self.context)
+        return_type.set_property("ServerRelativeUrl", new_url)
+        payload = {"newUrl": new_url}
+        qry = ServiceOperationQuery(self, "MoveTo", payload)
+        self.context.add_query(qry)
+        return return_type
+
+    def move_to_with_parameters(self, new_relative_url, retain_editor_and_modified=False):
+        """Moves the folder with files to the destination URL.
+
+        :type new_relative_url: str
+        :type retain_editor_and_modified: bool
+        """
+        return_type = Folder(self.context)
+        return_type.set_property("ServerRelativeUrl", new_relative_url)
+
+        def _move_folder():
+            opt = MoveCopyOptions(retain_editor_and_modified_on_move=retain_editor_and_modified)
+            MoveCopyUtil.move_folder(self.context, self.serverRelativeUrl, new_relative_url, opt)
+
+        self.ensure_property("ServerRelativeUrl", _move_folder)
+        return return_type
+
+    def move_to_using_path(self, new_path):
+        """
+        Moves the folder and its contents to a new folder at the specified path.
+
+        An exception is thrown if a folder with the same name as specified in the parameter already exists.
+
+        :param str new_path: Specifies the destination path.
+        """
+        params = SPResPath(new_path)
+        qry = ServiceOperationQuery(self, "MoveToUsingPath", params)
+        self.context.add_query(qry)
+        return self
+
+    def share_link(self, link_kind, expiration=None):
+        """Creates a tokenized sharing link for a folder based on the specified parameters and optionally
+        sends an email to the people that are listed in the specified parameters.
+
+        :param int link_kind: The kind of the tokenized sharing link to be created/updated or retrieved.
+        :param datetime or None expiration: A date/time string for which the format conforms to the ISO 8601:2004(E)
+            complete representation for calendar date and time of day and which represents the time and date of expiry
+            for the tokenized sharing link. Both the minutes and hour value MUST be specified for the difference
+            between the local and UTC time. Midnight is represented as 00:00:00. A null value indicates no expiry.
+            This value is only applicable to tokenized sharing links that are anonymous access links.
+        """
+        return self.list_item_all_fields.share_link(link_kind, expiration)
+
+    def unshare_link(self, link_kind, share_id=None):
+        """
+        Removes the specified tokenized sharing link of the folder.
+
+        :param int link_kind: This optional value specifies the globally unique identifier (GUID) of the tokenized
+            sharing link that is intended to be removed.
+        :param str or None share_id: The kind of tokenized sharing link that is intended to be removed.
+        """
+        return self.list_item_all_fields.unshare_link(link_kind, share_id)
+
     def recycle(self):
         """Moves the folder to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
 
@@ -40,8 +110,9 @@ class Folder(BaseEntity):
 
     def recycle_with_parameters(self, parameters):
         """
+        Moves the list folder to the Recycle Bin and returns the identifier of the new Recycle Bin item
 
-        :type parameters: office365.sharepoint.folders.folder_delete_parameters.FolderDeleteParameters
+        :type parameters: office365.sharepoint.folders.delete_parameters.FolderDeleteParameters
         """
         result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "RecycleWithParameters", None, parameters, "parameters", result)
@@ -114,13 +185,12 @@ class Folder(BaseEntity):
 
         def _copy_folder():
             opts = MoveCopyOptions(keep_both=keep_both, reset_author_and_created_on_copy=reset_author_and_created)
-            MoveCopyUtil.copy_folder(self.context, self._build_full_url(self.serverRelativeUrl),
-                                     self._build_full_url(new_relative_url), opts)
+            MoveCopyUtil.copy_folder(self.context, self.serverRelativeUrl, new_relative_url, opts)
 
         self.ensure_property("ServerRelativeUrl", _copy_folder)
         return target_folder
 
-    def copy_to_by_path(self, new_relative_path, keep_both=False, reset_author_and_created=False):
+    def copy_to_using_path(self, new_relative_path, keep_both=False, reset_author_and_created=False):
         """Copies the folder with files to the destination Path.
 
         :type new_relative_path: str
@@ -133,50 +203,31 @@ class Folder(BaseEntity):
 
         def _copy_folder():
             opts = MoveCopyOptions(keep_both=keep_both, reset_author_and_created_on_copy=reset_author_and_created)
-            MoveCopyUtil.copy_folder_by_path(self.context, self._build_full_url(self.server_relative_path.DecodedUrl),
-                                             self._build_full_url(new_relative_path), opts)
+            MoveCopyUtil.copy_folder_by_path(self.context, self.server_relative_path.DecodedUrl, new_relative_path,
+                                             opts)
 
         self.ensure_property("ServerRelativePath", _copy_folder)
         return target_folder
 
-    def move_to(self, new_relative_url, retain_editor_and_modified=False):
-        """Moves the folder with files to the destination URL.
-
-        :type new_relative_url: str
-        :type retain_editor_and_modified: bool
-        """
-        target_folder = Folder(self.context)
-        target_folder.set_property("ServerRelativeUrl", new_relative_url)
-
-        def _move_folder():
-            MoveCopyUtil.move_folder(self.context, self._build_full_url(self.serverRelativeUrl),
-                                     self._build_full_url(new_relative_url),
-                                     MoveCopyOptions(retain_editor_and_modified_on_move=retain_editor_and_modified))
-
-        self.ensure_property("ServerRelativeUrl", _move_folder)
-        return target_folder
-
-    def move_to_by_path(self, new_relative_path, retain_editor_and_modified=False):
+    def move_to_using_path_with_parameters(self, new_relative_path, retain_editor_and_modified=False):
         """Moves the folder with files to the destination Path.
 
-        :type new_relative_path: str
-        :type retain_editor_and_modified: bool
+        :param str new_relative_path: A full URL path that represents the destination folder.
+        :param bool retain_editor_and_modified:
         """
         target_folder = Folder(self.context)
         target_folder.set_property("ServerRelativePath", SPResPath(new_relative_path))
 
         def _move_folder():
-            MoveCopyUtil.move_folder_by_path(self.context, self._build_full_url(self.server_relative_path.DecodedUrl),
-                                             self._build_full_url(new_relative_path),
-                                             MoveCopyOptions(
-                                                 retain_editor_and_modified_on_move=retain_editor_and_modified))
+            opt = MoveCopyOptions(retain_editor_and_modified_on_move=retain_editor_and_modified)
+            MoveCopyUtil.move_folder_by_path(self.context, self.server_relative_path.DecodedUrl, new_relative_path, opt)
 
         self.ensure_property("ServerRelativePath", _move_folder)
         return target_folder
 
     @property
     def storage_metrics(self):
-        """"""
+        """Specifies the storage-related metrics for list folders in the site"""
         return self.properties.get("StorageMetrics",
                                    StorageMetrics(self.context, ResourcePath("StorageMetrics", self.resource_path)))
 
@@ -188,8 +239,8 @@ class Folder(BaseEntity):
 
     @property
     def files(self):
-        """Get a file collection"""
-        from office365.sharepoint.files.file_collection import FileCollection
+        """Specifies the collection of files contained in the list folder."""
+        from office365.sharepoint.files.collection import FileCollection
         return self.properties.get("Files",
                                    FileCollection(self.context, ResourcePath("Files", self.resource_path)))
 
@@ -203,30 +254,39 @@ class Folder(BaseEntity):
 
     @property
     def parent_folder(self):
-        """Specifies the list folder.
-        """
+        """Specifies the list folder."""
         return self.properties.get("ParentFolder",
                                    Folder(self.context, ResourcePath("ParentFolder", self.resource_path)))
 
     @property
     def name(self):
         """Specifies the list folder name.
+
         :rtype: str or None
         """
         return self.properties.get("Name", None)
 
     @property
     def is_wopi_enabled(self):
+        """
+        Indicates whether the folder is enabled for WOPI default action.
+
+        :rtype: bool or None
+        """
         return self.properties.get("IsWOPIEnabled", None)
 
     @property
     def prog_id(self):
-        """Gets the identifier (ID) of the application in which the folder was created."""
+        """Gets the identifier (ID) of the application in which the folder was created.
+
+        :rtype: str or None
+        """
         return self.properties.get("ProgID", None)
 
     @property
     def unique_id(self):
         """Gets the unique ID of the folder.
+
         :rtype: str or None
         """
         return self.properties.get("UniqueId", None)
@@ -234,6 +294,7 @@ class Folder(BaseEntity):
     @property
     def exists(self):
         """Gets a Boolean value that indicates whether the folder exists.
+
         :rtype: bool or None
         """
         return self.properties.get("Exists", None)
@@ -241,6 +302,7 @@ class Folder(BaseEntity):
     @property
     def welcome_page(self):
         """Specifies the server-relative URL for the list folder Welcome page.
+
         :rtype: str or None
         """
         return self.properties.get("WelcomePage", None)
@@ -269,9 +331,18 @@ class Folder(BaseEntity):
         """
         return self.properties.get("TimeLastModified", None)
 
+    @property
+    def time_created(self):
+        """Gets when the folder was created in UTC.
+
+        :rtype: datetime or None
+        """
+        return self.properties.get("TimeCreated", None)
+
     @property
     def serverRelativeUrl(self):
         """Gets the server-relative URL of the list folder.
+
         :rtype: str or None
         """
         return self.properties.get("ServerRelativeUrl", None)
@@ -281,7 +352,7 @@ class Folder(BaseEntity):
         """Gets the server-relative Path of the list folder.
         :rtype: SPResPath or None
         """
-        return self.properties.get("ServerRelativePath", SPResPath(None))
+        return self.properties.get("ServerRelativePath", SPResPath())
 
     def get_property(self, name, default_value=None):
         if default_value is None:
@@ -299,16 +370,10 @@ class Folder(BaseEntity):
     def set_property(self, name, value, persist_changes=True):
         super(Folder, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
-        if name == "ServerRelativeUrl":
-            self._resource_path = ServiceOperationPath("getFolderByServerRelativeUrl", [value], ResourcePath("Web"))
-        elif name == "ServerRelativePath":
-            self._resource_path = ServiceOperationPath("getFolderByServerRelativePath", [value], ResourcePath("Web"))
-        elif name == "UniqueId":
-            self._resource_path = ServiceOperationPath("getFolderById", [value], ResourcePath("Web"))
-
-    def _build_full_url(self, rel_url):
-        """
-        :type rel_url: str
-        """
-        site_path = urlparse(self.context.base_url).path
-        return self.context.base_url.replace(site_path, "") + rel_url
+        if name == "UniqueId":
+            self._resource_path = self.context.web.get_folder_by_id(value).resource_path
+        if self._resource_path is None:
+            if name == "ServerRelativeUrl":
+                self._resource_path = self.context.web.get_folder_by_server_relative_url(value).resource_path
+            elif name == "ServerRelativePath":
+                self._resource_path = self.context.web.get_folder_by_server_relative_path(value).resource_path
