@@ -1,41 +1,65 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.resource_path import ResourcePath
 from office365.runtime.paths.service_operation import ServiceOperationPath
-from office365.sharepoint.changes.change_collection import ChangeCollection
-from office365.sharepoint.changes.change_query import ChangeQuery
-from office365.sharepoint.contenttypes.content_type_collection import ContentTypeCollection
-from office365.sharepoint.customactions.custom_action_element import CustomActionElementCollection
-from office365.sharepoint.eventreceivers.event_receiver_definition import EventReceiverDefinitionCollection
-from office365.sharepoint.fields.field_collection import FieldCollection
+from office365.sharepoint.changes.collection import ChangeCollection
+from office365.sharepoint.changes.query import ChangeQuery
+from office365.sharepoint.changes.token import ChangeToken
+from office365.sharepoint.contenttypes.collection import ContentTypeCollection
+from office365.sharepoint.customactions.element import CustomActionElementCollection
+from office365.sharepoint.eventreceivers.definition import EventReceiverDefinitionCollection
+from office365.sharepoint.fields.collection import FieldCollection
 from office365.sharepoint.fields.related_field_collection import RelatedFieldCollection
 from office365.sharepoint.files.checkedOutFileCollection import CheckedOutFileCollection
 from office365.sharepoint.files.file import File
-from office365.sharepoint.flows.flow_synchronization_result import FlowSynchronizationResult
+from office365.sharepoint.flows.synchronization_result import FlowSynchronizationResult
 from office365.sharepoint.folders.folder import Folder
-from office365.sharepoint.forms.form_collection import FormCollection
-from office365.sharepoint.listitems.caml.caml_query import CamlQuery
+from office365.sharepoint.forms.collection import FormCollection
+from office365.sharepoint.listitems.caml.query import CamlQuery
 from office365.sharepoint.listitems.creation_information_using_path import ListItemCreationInformationUsingPath
 from office365.sharepoint.listitems.form_update_value import ListItemFormUpdateValue
 from office365.sharepoint.listitems.listitem import ListItem
-from office365.sharepoint.listitems.listItem_collection import ListItemCollection
+from office365.sharepoint.listitems.collection import ListItemCollection
+from office365.sharepoint.lists.creatables_info import CreatablesInfo
+from office365.sharepoint.lists.data_source import ListDataSource
 from office365.sharepoint.lists.list_rule import SPListRule
 from office365.sharepoint.pages.wiki_page_creation_information import WikiPageCreationInformation
 from office365.sharepoint.permissions.securable_object import SecurableObject
-from office365.sharepoint.usercustomactions.user_custom_action_collection import UserCustomActionCollection
+from office365.sharepoint.principal.user import User
+from office365.sharepoint.sitescripts.utility import SiteScriptUtility
+from office365.sharepoint.types.user_resource import UserResource
+from office365.sharepoint.usercustomactions.collection import UserCustomActionCollection
 from office365.sharepoint.views.view import View
 from office365.sharepoint.views.view_collection import ViewCollection
 from office365.sharepoint.webhooks.subscription_collection import SubscriptionCollection
 from office365.sharepoint.utilities.utility import Utility
+from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
 
 
 class List(SecurableObject):
-    """Represents a list on a SharePoint Web site."""
+    """Represents a list on a SharePoint Web site.
+
+    A container within a SharePoint site that stores list items. A list has a customizable schema that is
+    composed of one or more fields.
+    """
 
     def __init__(self, context, resource_path=None):
         super(List, self).__init__(context, resource_path)
 
+    def get_site_script(self, options=None):
+        """Creates site script syntax
+
+        :param dict or None options:
+        """
+        return_type = ClientResult(self.context)
+
+        def _list_loaded():
+            list_abs_url = self.context.create_safe_url(self.root_folder.serverRelativeUrl, False)
+            SiteScriptUtility.get_site_script_from_list(self.context, list_abs_url, options, return_type=return_type)
+        self.ensure_property("RootFolder", _list_loaded)
+        return return_type
+
     def get_all_rules(self):
         return_type = ClientResult(self.context, ClientValueCollection(SPListRule))
         qry = ServiceOperationQuery(self, "GetAllRules", None, None, None, return_type)
@@ -88,10 +112,13 @@ class List(SecurableObject):
 
     def create_document_with_default_name(self, folder_path, extension):
         """
-        :param str folder_path:
-        :param str extension:
+        Creates a empty document with default filename with the given extension at the path given by folderPath.
+        Returns the name of the newly created document.
+
+        :param str folder_path: The path within the current list at which to create the document.
+        :param str extension: The file extension without dot prefix.
         """
-        return_type = FlowSynchronizationResult(self.context)
+        return_type = ClientResult(self.context)
         payload = {
             "folderPath": folder_path,
             "extension": extension
@@ -109,8 +136,11 @@ class List(SecurableObject):
 
     def render_list_data(self, view_xml):
         """
+        Returns the data for the specified query view.<56> The result is implementation-specific, used for
+        providing data to a user interface.
 
-        :param str view_xml: View xml
+        :param str view_xml:  Specifies the query as XML that conforms to the ViewDefinition type as specified in
+            [MS-WSSCAML] section 2.3.2.17.
         """
         result = ClientResult(self.context)
         payload = {
@@ -183,7 +213,7 @@ class List(SecurableObject):
         Returns the changes made to the list since the date and time specified in the change token defined
         by the query input parameter.<57>
 
-        :type query: office365.sharepoint.changes.change_log_item_query.ChangeLogItemQuery
+        :type query: office365.sharepoint.changes.log_item_query.ChangeLogItemQuery
         """
         result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "getListItemChangesSinceToken", None, query, "query", result)
@@ -215,7 +245,7 @@ class List(SecurableObject):
         """
         Returns the list item with the specified ID.
 
-        :param str unique_id:
+        :param str unique_id: The unique ID that is associated with the list item.
 
         """
         return ListItem(self.context,
@@ -296,27 +326,48 @@ class List(SecurableObject):
 
     def add_item_using_path(self, leaf_name, object_type, folder_url):
         """
-        :type leaf_name: str
-        :type object_type: int
-        :type folder_url: str
-        """
-        from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
-        parameters = ListItemCreationInformationUsingPath(leaf_name, object_type, folder_path=SPResPath(folder_url))
-        item = ListItem(self.context)
-        qry = ServiceOperationQuery(self, "AddItemUsingPath", None, parameters, "parameters", item)
-        self.context.add_query(qry)
-        return item
+        Adds a ListItem to an existing List.
 
-    def add_validate_update_item(self):
-        pass
+        :param str leaf_name: Specifies the name of the list item that will be created. In the case of a
+            document library, the name is equal to the filename of the list item.
+        :param int object_type: Specifies the file system object type for the item that will be created.
+            It MUST be either FileSystemObjectType.File or FileSystemObjectType.Folder.
+        :param str ot None folder_url: Specifies the url of the folder of the new list item.
+            The value MUST be either null or the decoded url value an empty string or a server-relative
+            URL or an absolute URL. If the value is not null or the decoded url value not being empty string,
+            the decoded url value MUST point to a location within the list.
+        """
+        parameters = ListItemCreationInformationUsingPath(leaf_name, object_type, folder_path=folder_url)
+        return_type = ListItem(self.context)
+        qry = ServiceOperationQuery(self, "AddItemUsingPath", None, parameters, "parameters", return_type)
+        self.context.add_query(qry)
+        return return_type
+
+    def add_validate_update_item(self, create_info, form_values=None):
+        """
+        Adds an item to an existing list and validate the list item update values. If all fields validated successfully,
+         commit all changes. If there's any exception in any of the fields, the item will not be committed.
+
+        :param ListItemCreationInformation create_info:  Contains the information that determines how the item
+            will be created.
+        :param dict form_values: A collection of field internal names and values for the given field. If the collection
+            is empty, no update will take place.
+        """
+        payload = {
+            "listItemCreateInfo": create_info,
+            "formValues": [ListItemFormUpdateValue(k, v) for k, v in form_values.items()]
+        }
+        return_type = ClientResult(self.context, ClientValueCollection(ListItemFormUpdateValue))
+        qry = ServiceOperationQuery(self, "AddValidateUpdateItem", None, payload, None, return_type)
+        self.context.add_query(qry)
+        return return_type
 
     def get_item_by_id(self, item_id):
         """Returns the list item with the specified list item identifier.
 
         :type item_id: int
         """
-        return ListItem(self.context,
-                        ServiceOperationPath("getItemById", [item_id], self.resource_path))
+        return ListItem(self.context, ServiceOperationPath("getItemById", [item_id], self.resource_path))
 
     def get_view(self, view_id):
         """Returns the list view with the specified view identifier.
@@ -339,10 +390,11 @@ class List(SecurableObject):
         return changes
 
     def get_checked_out_files(self):
-        result = CheckedOutFileCollection(self.context)
-        qry = ServiceOperationQuery(self, "GetCheckedOutFiles", None, None, None, result)
+        """Returns a collection of checked-out files as specified in section 3.2.5.381."""
+        return_type = CheckedOutFileCollection(self.context)
+        qry = ServiceOperationQuery(self, "GetCheckedOutFiles", None, None, None, return_type)
         self.context.add_query(qry)
-        return result
+        return return_type
 
     def reserve_list_item_id(self):
         """
@@ -357,17 +409,88 @@ class List(SecurableObject):
         """Returns a collection of lookup fields that use this list as a data source and
             that have FieldLookup.IsRelationship set to true.
         """
-        return RelatedFieldCollection(self.context,
-                                      ServiceOperationPath("getRelatedFields", [], self.resource_path))
+        return RelatedFieldCollection(self.context, ServiceOperationPath("getRelatedFields", [], self.resource_path))
 
     @property
     def id(self):
         """
         Gets a value that specifies the list identifier.
+
         :rtype: str
         """
         return self.properties.get("Id", None)
 
+    @property
+    def author(self):
+        """Specifies the user who created the list."""
+        return self.properties.get('Author',
+                                   User(self.context, ResourcePath("Author", self.resource_path)))
+
+    @property
+    def allow_content_types(self):
+        """
+        Specifies whether the list supports content types.
+
+        :rtype: bool or None
+        """
+        return self.properties.get("AllowContentTypes", None)
+
+    @property
+    def base_template(self):
+        """
+        Specifies the list server template of the list.
+
+        :rtype: int or None
+        """
+        return self.properties.get("BaseTemplate", None)
+
+    @property
+    def base_type(self):
+        """
+        Specifies the base type of the list.
+        It MUST be one of the following values: GenericList, DocumentLibrary, DiscussionBoard, Survey, or Issue.
+
+        :rtype: int or None
+        """
+        return self.properties.get("BaseType", None)
+
+    @property
+    def crawl_non_default_views(self):
+        """
+        Specifies whether or not the crawler indexes the non-default views of the list.
+        Specify a value of true if the crawler indexes the list's non-default views; specify false if otherwise.
+
+        :rtype: bool or None
+        """
+        return self.properties.get("CrawlNonDefaultViews", None)
+
+    @property
+    def creatables_info(self):
+        """
+        Returns an object that describes what this list can create, and a collection of links to visit in order to
+        create those things. If it can't create certain things, it contains an error message describing why.
+
+         The consumer MUST append the encoded URL of the current page to the links returned here.
+         (This page the link goes to needs it as a query parameter to function correctly.)
+         The consumer SHOULD also consider appending &IsDlg=1 to the link, to remove the UI from the linked page,
+         if desired.
+        """
+        return self.properties.get('CreatablesInfo',
+                                   CreatablesInfo(self.context, ResourcePath("CreatablesInfo", self.resource_path)))
+
+    @property
+    def current_change_token(self):
+        """Gets the current change token that is used in the change log for the list."""
+        return self.properties.get("CurrentChangeToken", ChangeToken())
+
+    @property
+    def data_source(self):
+        """
+        Specifies the data source of an external list.
+        If HasExternalDataSource is "false", the server MUST return NULL.
+        """
+        return self.properties.get("DataSource", ListDataSource())
+
     @property
     def enable_folder_creation(self):
         """
@@ -500,19 +623,65 @@ class List(SecurableObject):
         """Sets the description for the list."""
         self.set_property('Description', val)
 
+    @property
+    def description_resource(self):
+        """Represents the description of this list."""
+        return self.properties.get('DescriptionResource',
+                                   UserResource(self.context, ResourcePath("DescriptionResource", self.resource_path)))
+
     @property
     def parent_web_path(self):
-        return self.properties.get('ParentWebPath', None)
+        """Returns the path of the parent web for the list."""
+        return self.properties.get('ParentWebPath', SPResPath())
+
+    @property
+    def schema_xml(self):
+        """Specifies the list schema of the list.
+
+        :rtype: str or None
+        """
+        return self.properties.get("SchemaXml", None)
+
+    @property
+    def template_feature_id(self):
+        """
+        Specifies the feature identifier of the feature that contains the list schema for the list.
+        It MUST be an empty GUID if the list schema for the list is not contained within a feature.
+
+        :rtype: str or None
+        """
+        return self.properties.get("TemplateFeatureId", None)
+
+    @property
+    def title_resource(self):
+        """Represents the title of this list."""
+        return self.properties.get('TitleResource',
+                                   UserResource(self.context, ResourcePath("TitleResource", self.resource_path)))
+
+    @property
+    def validation_formula(self):
+        """
+        Specifies the data validation criteria for a list item.
+
+        :rtype: str or None
+        """
+        return self.properties.get("ValidationFormula", None)
 
     def get_property(self, name, default_value=None):
         if default_value is None:
             property_mapping = {
+                "CreatablesInfo": self.creatables_info,
+                "CurrentChangeToken": self.current_change_token,
                 "ContentTypes": self.content_types,
                 "CustomActionElements": self.custom_action_elements,
+                "DataSource": self.data_source,
+                "DescriptionResource": self.description_resource,
                 "DefaultView": self.default_view,
                 "EventReceivers": self.event_receivers,
                 "ParentWeb": self.parent_web,
+                "ParentWebPath": self.parent_web_path,
                 "RootFolder": self.root_folder,
+                "TitleResource": self.title_resource,
                 "UserCustomActions": self.user_custom_actions
             }
             default_value = property_mapping.get(name, None)
