@@ -1,35 +1,28 @@
-from office365.runtime.queries.create_entity_query import CreateEntityQuery
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.create_entity import CreateEntityQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.runtime.paths.service_operation import ServiceOperationPath
 from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.principal.user import User
 
 
 class UserCollection(BaseEntityCollection):
-    """Represents a collection of User resources."""
 
     def __init__(self, context, resource_path=None):
+        """Represents a collection of User resources."""
         super(UserCollection, self).__init__(context, User, resource_path)
 
-    def get(self):
-        """
-        :rtype: UserCollection
-        """
-        return super(UserCollection, self).get()
-
     def add_user(self, login_name):
         """
-        Adds a user
+        Creates a user
 
         :type login_name: str
         """
-        user = User(self.context)
-        user._parent_collection = self
-        user.set_property('LoginName', login_name)
-        qry = CreateEntityQuery(self, user, user)
+        return_type = User(self.context)
+        self.add_child(return_type)
+        return_type.set_property('LoginName', login_name)
+        qry = CreateEntityQuery(self, return_type, return_type)
         self.context.add_query(qry)
-        self.add_child(user)
-        return user
+        return return_type
 
     def get_by_email(self, email):
         """Retrieve User object by email
@@ -47,8 +40,7 @@ class UserCollection(BaseEntityCollection):
 
         :type login_name: str
         """
-        return User(self.context,
-                    ServiceOperationPath("GetByLoginName", [login_name], self.resource_path))
+        return User(self.context, ServiceOperationPath("GetByLoginName", [login_name], self.resource_path))
 
     def remove_by_id(self, _id):
         """Retrieve User object by id"""
@@ -57,7 +49,10 @@ class UserCollection(BaseEntityCollection):
         return self
 
     def remove_by_login_name(self, login_name):
-        """Remove User object by login name"""
+        """Remove User object by login name
+
+        :param str login_name:
+        """
         qry = ServiceOperationQuery(self, "RemoveByLoginName", [login_name])
         self.context.add_query(qry)
         return self
