@@ -6,7 +6,7 @@ from office365.runtime.compat import quote
 from office365.entity import Entity
 from office365.onedrive.driveitems.driveItem import DriveItem
 from office365.runtime.paths.resource_path import ResourcePath
-from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.service_operation import ServiceOperationQuery
 from office365.teams.channels.conversation_member import ConversationMember
 from office365.teams.messages.chat_message import ChatMessage
 from office365.teams.tabs.tab import TeamsTab
